#
# spec file for package libxcam
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   1
%define libname %{name}%{sover}
Name:           libxcam
Version:        1.5.0
Release:        5.8
Summary:        Image processing library for extended camera features and video analysis
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            https://github.com/01org/libxcam
Source0:        https://github.com/01org/libxcam/archive/release_%{version}.tar.gz
# PATCH-FIX-UPSTREAM OpenCV 4.x support, part 1
Patch0:         https://github.com/intel/libxcam/commit/b40c249bcfbf85da66fba416c6480d5ac6ff2ecb.patch#/0001-gl-stitch_support_EGL_initialize_by_GBM.patch
# PATCH-FIX-UPSTREAM OpenCV 4.x support, part 2
Patch1:         https://github.com/intel/libxcam/commit/6a20559b402493ff29eac7368b5d7b4569a64884.patch#/0001-New_features_camera_tunning_and_fixes.patch
# PATCH-FIX-UPSTREAM OpenCV 4.x support, part 3
Patch2:         https://github.com/intel/libxcam/commit/ea99d89082c2473c2e22c848bff4f9f537af3fde.patch#/0001-pkg_config_check_opencv_module_version.patch
# PATCH-FIX-UPSTREAM Fix ODR violation
Patch3:         0001-Fix-multiple-definitions-of-XCam-ShaderID-ODR-violat.patch
# PATCH-FIX-UPSTREAM Fix build with GCC 12
Patch4:         https://github.com/intel/libxcam/pull/802/commits/d13b69e6332277a4a59cd736439e17851fe8be74.patch#/libxcam-1.5.0-gcc-12.patch
# PATCH-FIX-OPENSUSE Fix FTBFS error
Patch5:         fix-missing-include.patch
BuildRequires:  Mesa-libGLESv3-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  gstreamer-devel
BuildRequires:  gstreamer-plugins-base-devel
BuildRequires:  libtool
BuildRequires:  ocl-icd-devel
BuildRequires:  opencl-headers
BuildRequires:  pkgconfig
%ifarch %{ix86} x86_64
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libdrm_intel)
%endif
%if 0%{?suse_version} >= 1550
BuildRequires:  pkgconfig(opencv4)
%else
BuildRequires:  pkgconfig(opencv)
%endif
BuildRequires:  pkgconfig(vulkan)

%description
libXCam is a project for extended camera features and focus on image quality
improvement and video analysis. There are lots features supported in image
pre-processing, image post-processing and smart analysis. This library makes
GPU/CPU/ISP working together to improve image quality. OpenCL is used to improve
performance in different platforms.

%package -n %{libname}
Summary:        Image processing library for extended camera features and video analysis
Group:          System/Libraries

%description -n %{libname}
libXCam is a project for extended camera features and focus on image quality
improvement and video analysis. There are lots features supported in image
pre-processing, image post-processing and smart analysis. This library makes
GPU/CPU/ISP working together to improve image quality. OpenCL is used to improve
performance in different platforms.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%autosetup -p1 -n %{name}-release_%{version}

%build
%ifarch ppc64le
export CXXFLAGS="$CXXFLAGS -std=gnu++11"
%endif

autoreconf -fiv
%configure \
   --disable-static \
   --with-package-name="Libxcam (openSUSE)" \
   --with-package-origin="http://www.opensuse.org/" \
%ifarch %{ix86} x86_64
   --enable-drm \
%endif
   --disable-aiq \
   --enable-gst \
   --enable-gles \
   --enable-libcl \
   --enable-vulkan \
   --enable-opencv \
   --enable-capi \
   --disable-3alib \
   --enable-smartlib
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%doc README.md NOTICE
%license COPYING
%{_libdir}/%{name}_capi.so.%{sover}*
%{_libdir}/%{name}_core.so.%{sover}*
%{_libdir}/%{name}_gles.so.%{sover}*
%{_libdir}/%{name}_ocl.so.%{sover}*
%{_libdir}/%{name}_soft.so.%{sover}*
%{_libdir}/%{name}_vulkan.so.%{sover}*
%{_libdir}/gstreamer-1.0/libgstxcamsrc.so
%{_libdir}/gstreamer-1.0/libgstxcamfilter.so

%files devel
%{_includedir}/xcam
%{_libdir}/pkgconfig/libxcam.pc
%{_libdir}/libxcam_capi.so
%{_libdir}/libxcam_core.so
%{_libdir}/libxcam_gles.so
%{_libdir}/libxcam_ocl.so
%{_libdir}/libxcam_soft.so
%{_libdir}/libxcam_vulkan.so

%changelog
* Mon Jan 22 2024 Antonio Larrosa <alarrosa@suse.com>
- Add patch to fix a FTBFS error due to missing include:
  * fix-missing-include.patch
* Mon Jul  4 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Re-generated patches based on upstream commits (osc service ra
  download_files):
  M 0001-New_features_camera_tunning_and_fixes.patch
  M 0001-gl-stitch_support_EGL_initialize_by_GBM.patch
* Mon Jun 27 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Add libxcam-1.5.0-gcc-12.patch: Fix build with gcc 12 (gh#intel/libxcam#801).
* Fri Apr 29 2022 Antonio Larrosa <alarrosa@suse.com>
- Use -std=gnu++11 in ppc64le to work around a bug in gcc7 which
  redefines bool in altivec.h thus making all code that uses bool
  fail to build (boo#1195517)
* Fri Dec 17 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Really build against OpenCV4 (on TW), add
  * 0001-gl-stitch_support_EGL_initialize_by_GBM.patch
  * 0001-New_features_camera_tunning_and_fixes.patch
  * 0001-pkg_config_check_opencv_module_version.patch
- Fix ODR violation, add
  * 0001-Fix-multiple-definitions-of-XCam-ShaderID-ODR-violat.patch
* Mon Oct 18 2021 Dirk Müller <dmueller@suse.com>
- update to 1.5.0:
  * 360 stitching GLES pipeline supports processing YUV420p pixel format
- drop Fix-build-with-Vulkan-1.2.140.patch (upstream)
- build against openCV 4
* Thu Jul 23 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 1.4.0:
  * 360 stitching supports processing YUV420p pixel format
  * 360 degree image stitching quality tuning
  - support json parse to apply OpenCV fisheye camera calibration parameters
  * 8K 360 degree image stitching performance improvement
  - optimized AVX pixel data loading instructions
  * Simplify configure.ac
  - extract macros to m4 file
  * Remove Beignet dependence
  * Limit OpenCV version to [3.0.0, 4.0.0)
  * Extend the functionality of capi module
  - support soft/GLES/Vulkan image stitching
  - implement new FFmpeg xcam video filter
- Update to version 1.3.0:
  * 8K 360 degree image stitching performance improvement
  - enable AVX512 intrinsic instructions to increase performance
  * 3 cameras 8K stitching enabling (CPU/GLES)
  - support disable feature match in runtime
  - support specify the pyramid levels of blender
  - stitching quality tuning
  * 2 cameras 1080p stitching enabling (CPU/GLES)
  * DNN inference support processing video stream
  * Use Intel open source graphics compute runtime for OpenCL (NEO)
  - will not support Beignet driver
- Remove obsolete allow-newer-opencv.patch
- Add Fix-build-with-Vulkan-1.2.140.patch
- Removed obsolete or irrelevant build dependencies
- Enable build for all architectures, disable DRM for everything
  but Intel.
* Thu May 21 2020 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 1.2.2
  * GLES compute framework enabling.
  - enable GL image processing framework.
  - enable features of multi-band blender, geometry remap and data-copy.
  * GLES surround-view stitching enabling.
  - GLES stitching enabled (feature-match may support later).
  - performance optimized on compute shaders.
  * Vulkan compute framework enabling.
  - enabled Vulkan image processing under xcam framework.
  - vk-copy-handler as sample code.
  * suggest OpenCV version [3.0.0 - 3.4.3]
  * support CPU stitching based on dual-const and dual-curve scaling factors.
  * support OpenCL stitching based on auto-scale in vertical 2D-direction.
  * change test-soft-image to test-surround-view
  * Vulkan surround-view stitching enabling.
  - enable features of multi-band blender and geometry remap.
  - enable Vulkan image stitching. (feature-match may support later)
  * Surrond-view texture rendering.
  - enable 3D surround view scene rendering and manipulation.
  * require OpenSceneGraph minimal version 3.3.2
  * DNN inference framwork enabling.
  - enable pedestrian and vehicle detection based on OpenVino
  * OpenCV feature match enabled for image stitching pipeline (GLES/Vulkan/CPU)
  - support three versions of feature match: default, cluster, capi
  * Abstract OpenCV source in ocv module, and build into a separate static library
- Require pkgconfig(opencv), because this still needs OpenCV 3.
- Add allow-newer-opencv.patch: Allow all 3.x.x versions.
- Disable 3alib to prevent compiler errors due to missing linux/atomisp.h.
- Enable Vulkan support.
* Tue Oct  2 2018 Antonio Larrosa <alarrosa@suse.com> - 1.1.0
- Update to version 1.1.0
  * CPU stitching enabled for automotive surround view in Linux/Android.
  - enable CPU multi-thread image processing framework.
  - enable multi-band blender, geometry remap, data-copy, OpenCV feature match.
  - enable 3D-bowl model stitching.
  - support generic Android platform.
  - CPU version of surround view stitching upstream to Android Open Source Project.
  * surround-view OpenCL stitching feature enabled and quality improvement.
  - add dewarp process based on bowl view model in geometry map.
  - support multiple (4) cameras stitching.
  - add new selection method based on clustering in feature match to improve quality of stitching.
  - auto scale in x direction is done and y direction is WIP.
  - quality tune on different datasets, both indoor and outdoor.
  * support standard OpenCL 2.0+ driver (VPG OCL driver)
  - support standard OpenCL buffer.
  - remove libdrm dependency.
  - drm preview removed from test-device-manager, test-pipe-manager and usb camera.
  * enable deblurring feature based on OpenCV. (GSoC program)
  - based on deconvolution algorithm filters
  - support noise estimation
  - support edgetaper
  * surround view solution will be integrated into Android EVS (exterior view system) WIP
  * add sample recipe for yocto build (libxcam/doc/yocto).
* Thu Oct 12 2017 jengelh@inai.de
- Update package summary.
* Mon Sep  4 2017 alarrosa@suse.com
- Update to version 1.0.0
  * 360 video stitching performance and quality improvement.
  - enable geometry map to improve performance.
  - quality tuned on different resolutions (1080P and 4K).
  - support CPU and OpenCL path in feature match.
  - enable lens shading correction based on fisheye image.
  * gyroscope-based video stabilization enabling.
  - enable gyroscope 3-DoF (orientation) assist video stabilization.
  - orientation (gyro) data should be measured by quaternion as the pose
    of target frame reference to base frame
  * CL framework refine.
  - enable CL argument template instead of member variables in kernel.
  - CL kernel support async mode.
  - image handler take over input/output buffer management from image kernel.
  * prepare libxcam debian package and fix most warnings.
- Remove fix-build-errors.diff which is no longer required
- Increased soname to 1
- The pkgconfig file has been renamed from xcam to libxcam
* Thu May 11 2017 alarrosa@suse.com
- Use --disable-aiq when configuring libxcam.
  AIQ/ia_imaging is an Intel proprietary 3A library.
* Tue May  9 2017 alarrosa@suse.com
- Initial release of libxcam
- Version 0.9.0
- Add fix-build-errors.diff to build correctly
